@@ -15,14 +15,14 @@ test_that("basic",{
 
     file.lst.2 <- NMdata_filepath("examples/nonmem/xgxr002.lst")
 
-    res2 <- NMscanData(file=file.lst.2, check.time = FALSE, merge.by.row=FALSE)
+    res2 <- NMscanData(file=file.lst.2, check.time = FALSE, merge.by.row=FALSE,quiet=TRUE)
 
     ## can't rbind data.frames - cols don't match
     expect_error(rbind(res1,res2,fill=T))
 
     NMdataConf(as.fun="data.table")
     res1 <- NMscanData(file=file.lst.1, quiet=T, order.columns = F, merge.by.row=FALSE, check.time = FALSE)
-    res2 <- NMscanData(file=file.lst.2, check.time = FALSE, merge.by.row=FALSE)
+    res2 <- NMscanData(file=file.lst.2, check.time = FALSE, merge.by.row=FALSE,quiet=TRUE)
 
     expect_equal(is.NMdata(res1),TRUE)
     
